from setuptools import setup

setup(name='pystat_distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['pystat_distributions'],
      author = 'Tara Haddadin',
      author_email = 'tara_haddadin@yahoo.com',
      zip_safe=False)
